summaryrefslogtreecommitdiff
path: root/src/dropbox-client.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/dropbox-client.h')
-rw-r--r--src/dropbox-client.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/dropbox-client.h b/src/dropbox-client.h
index c981c44..29c7eb4 100644
--- a/src/dropbox-client.h
+++ b/src/dropbox-client.h
@@ -4,20 +4,20 @@
* dropbox-client.h
* Header file for dropbox-client.c
*
* This file is part of nautilus-dropbox.
*
* nautilus-dropbox is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* nautilus-dropbox is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with nautilus-dropbox. If not, see <http://www.gnu.org/licenses/>.
+ * along with caja-dropbox. If not, see <http://www.gnu.org/licenses/>.
*
*/
@@ -26,13 +26,13 @@
#include <glib.h>
#include "dropbox-command-client.h"
-#include "nautilus-dropbox-hooks.h"
+#include "caja-dropbox-hooks.h"
G_BEGIN_DECLS
typedef struct {
DropboxCommandClient dcc;
- NautilusDropboxHookserv hookserv;
+ CajaDropboxHookserv hookserv;
GHookList onconnect_hooklist;
GHookList ondisconnect_hooklist;
gboolean hook_connect_called;
@@ -4,20 +4,20 @@
* Header file for dropbox-client.c
*
- * This file is part of nautilus-dropbox.
+ * This file is part of caja-dropbox.
*
@@ -4,20 +4,20 @@
*
- * nautilus-dropbox is free software: you can redistribute it and/or modify
+ * caja-dropbox is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
@@ -4,20 +4,20 @@
* (at your option) any later version.
*
- * nautilus-dropbox is distributed in the hope that it will be useful,
+ * caja-dropbox is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the